import { Component } from '@angular/core';
import * as Diagramming from '@mindfusion/diagramming';
import * as Drawing from '@mindfusion/drawing';

@Component({
  selector: 'anchor-points',
  templateUrl: './anchor-points.html'
})
export class AnchorPoints {

  diagram: Diagramming.Diagram;
  decision1In3Out: Diagramming.AnchorPattern;
  apat2: Diagramming.AnchorPattern;

  constructor() {
    this.diagram = new Diagramming.Diagram();

    var theme = new Diagramming.Theme();
    var shapeNodeStyle = new Diagramming.Style();
    shapeNodeStyle.brush = {
      type: "LinearGradientBrush",
      color1: "#e0e9e9",
      color2: "#616a7f",
      angle: 90,
    };
    shapeNodeStyle.stroke = "#7F7F7F";
    shapeNodeStyle.textColor = "#585A5C";
    shapeNodeStyle.fontName = "Verdana";
    shapeNodeStyle.fontSize = 3;
    shapeNodeStyle.backBrush = "#e0e9e9";
    shapeNodeStyle.nodeEffects = [new Diagramming.GlassEffect()];
    theme.styles.set("std:ShapeNode", shapeNodeStyle);
    this.diagram.theme = theme;

    var blue = "#2d3956";
    var green = "#5a7444";
    var red = "#ce0000";

    var apat1 = new Diagramming.AnchorPattern([
      new Diagramming.AnchorPoint(50, 0, true, true),
      new Diagramming.AnchorPoint(100, 50, true, true),
      new Diagramming.AnchorPoint(50, 100, true, true),
      new Diagramming.AnchorPoint(0, 50, true, true)
    ]);
    this.apat2 = new Diagramming.AnchorPattern([
      new Diagramming.AnchorPoint(10, 0, true, false, Diagramming.MarkStyle.Circle, green),
      new Diagramming.AnchorPoint(50, 0, true, false, Diagramming.MarkStyle.Circle, blue),
      new Diagramming.AnchorPoint(90, 0, true, false, Diagramming.MarkStyle.Circle, red),
      new Diagramming.AnchorPoint(10, 100, false, true, Diagramming.MarkStyle.Rectangle),
      new Diagramming.AnchorPoint(50, 100, false, true, Diagramming.MarkStyle.Rectangle),
      new Diagramming.AnchorPoint(90, 100, false, true, Diagramming.MarkStyle.Rectangle),
      new Diagramming.AnchorPoint(0, 50, true, true, Diagramming.MarkStyle.X)
    ]);

    var pb1 = this.diagram.factory.createShapeNode(new Drawing.Rect(10, 7, 25, 18));
    pb1.shape = "Ellipse";
    pb1.text = "Start";
    pb1.anchorPattern = apat1;

    var pb2 = this.diagram.factory.createShapeNode(new Drawing.Rect(20, 78, 25, 18));
    pb2.text = "node 1";
    pb2.anchorPattern = this.apat2;

    var pb3 = this.diagram.factory.createShapeNode(new Drawing.Rect(70, 73, 25, 18));
    pb3.text = "node 2";
    pb3.anchorPattern = this.apat2;

    var pb4 = this.diagram.factory.createShapeNode(new Drawing.Rect(80, 110, 25, 18));
    pb4.shape = "Ellipse";
    pb4.text = "End";
    pb4.anchorPattern = apat1;

    this.decision1In3Out = Diagramming.AnchorPattern.fromId("Decision1In3Out");

    var decb1 = this.diagram.factory.createShapeNode(new Drawing.Rect(20, 35, 30, 20));
    decb1.shape = "Decision";
    decb1.text = "check 1";
    decb1.anchorPattern = this.decision1In3Out;

    var decision2In2Out = Diagramming.AnchorPattern.fromId("Decision2In2Out");

    var decb2 = this.diagram.factory.createShapeNode(new Drawing.Rect(70, 30, 30, 20));
    decb2.shape = "Decision";
    decb2.text = "check 2";
    decb2.anchorPattern = decision2In2Out;

    var link = this.diagram.factory.createDiagramLink(decb1, decb2);
    link.route();
  }

  onDiagramNodeCreated(event: any) {
    var node = event.args.node;
    if (event.sender.defaultShape.id === "Rectangle")
      node.anchorPattern = this.apat2;
    else
      node.anchorPattern = this.decision1In3Out;
  }

  onShapeChange(e: any) {
    this.diagram.defaultShape = e.target.value;
  }
}