import { AfterViewInit, Component } from '@angular/core'
import * as Diagramming from '@mindfusion/diagramming';
import * as Drawing from '@mindfusion/drawing';

const OrgChartNode = Diagramming.CompositeNode.classFromTemplate("OrgChartNode", {
    component: "GridPanel",
    rowDefinitions: ["*"],
    columnDefinitions: ["22", "*"],
    children:
        [
            {
                component: "Rect",
                name: "Background",
                pen: "black",
                brush: "white",
                columnSpan: 2
            },
            {
                component: "Image",
                name: "Image",
                autoProperty: true,
                location: "ceo.png",
                margin: "1",
                imageAlign: "Fit"
            },
            {
                component: "StackPanel",
                orientation: "Vertical",
                gridColumn: 1,
                margin: "1",
                verticalAlignment: "Near",
                children:
                    [
                        {
                            component: "Text",
                            name: "Title",
                            autoProperty: true,
                            text: "title",
                            font: "Arial bold"
                        },
                        {
                            component: "Text",
                            name: "FullName",
                            autoProperty: true,
                            text: "full name",
                            pen: "blue",
                            padding: "1,0,1,0"
                        },
                        {
                            component: "Text",
                            name: "Details",
                            autoProperty: true,
                            text: "details",
                            font: "Arial 3"
                        }
                    ]
            }
        ]
});

// Create a type definition and declare the dynamic 
// auto properties from the template above.
// This step is optional, and the intent is to use intersecting types to avoid casting to 'any'
// when setting the dynamically created properties.
type AutoProps =
    {
        image: string;
        title: string;
        fullName: string;
        details: string;
    }

@Component({
    selector: 'composte-nodes',
    templateUrl: './composite-nodes.html'
})
export class CompositeNodes implements AfterViewInit {

    diagram!: Diagramming.Diagram;
    behavior: Diagramming.Behavior = Diagramming.Behavior.DrawLinks;

    constructor() {
        // create diagram 
        this.diagram = new Diagramming.Diagram();
    }

    ngAfterViewInit(): void {
        // merge with AutoProps to have compile-time support for the templated dynamic auto properties (optional).
        let node1 = new OrgChartNode(this.diagram) as Diagramming.CompositeNode & AutoProps;
        node1.bounds = new Drawing.Rect(25, 15, 60, 25);
        node1.title = "CEO";
        node1.fullName = "John Smith";
        node1.details =
            "Our beloved leader. \r\n" +
            "The CEO of this great corporation.";
        node1.image = '../assets/ceo.png';
        this.diagram.addItem(node1);

        let node2 = new OrgChartNode(this.diagram) as Diagramming.CompositeNode & AutoProps;
        node2.bounds = new Drawing.Rect(25, 55, 60, 25);
        node2.title = "CTO";
        node2.fullName = "Bob Smith";
        node2.details = "The technology chief of this great corporation.";
        node2.image = '../assets/cto.png';
        this.diagram.addItem(node2);

        let node3 = new OrgChartNode(this.diagram) as Diagramming.CompositeNode & AutoProps;
        node3.bounds = new Drawing.Rect(95, 55, 60, 25);
        node3.title = "HR";
        node3.fullName = "Mary Johnson";
        node3.details = "Human resources and staff development.";
        node3.image = '../assets/hr.png';
        this.diagram.addItem(node3);

        let node4 = new OrgChartNode(this.diagram) as Diagramming.CompositeNode & AutoProps;
        node4.bounds = new Drawing.Rect(175, 55, 60, 25);
        node4.title = "PR";
        node4.fullName = "Diana Brandson";
        node4.details = "Public relations and media.";
        node4.image = '../assets/pr.png';
        this.diagram.addItem(node4);

        let node5 = new OrgChartNode(this.diagram) as Diagramming.CompositeNode & AutoProps;
        node5.bounds = new Drawing.Rect(175, 95, 60, 25);
        node5.title = "Media";
        node5.fullName = "Dave Lu";
        node5.details = "Adertising and creative content.";
        node5.image = '../assets/ad.png';
        this.diagram.addItem(node5);

        this.diagram.factory.createDiagramLink(node1, node2);
        this.diagram.factory.createDiagramLink(node1, node3);
        this.diagram.factory.createDiagramLink(node1, node4);
        this.diagram.factory.createDiagramLink(node4, node5);
    }
}