import { Component, ViewChild } from '@angular/core';
import * as DControls from '@mindfusion/diagramming-controls';
import * as Diagramming from '@mindfusion/diagramming';
import { TabbedDiagramView, Overview } from '@mindfusion/diagramming-angular';
import { Dialogs, ModalResult } from '@mindfusion/common-ui';

@Component({
  selector: 'tabbed-view',
  templateUrl: './tabbed-view.html'
})
export class TabbedView {
  @ViewChild(TabbedDiagramView) diagramViewControl!: TabbedDiagramView;
  tabAlignment: DControls.TabAlignment = DControls.TabAlignment.Top;
  showNavigationButtons: boolean = true;
  showAddButton: boolean = true;
  showTabCloseButtons: boolean = false;
  theme: Diagramming.Theme | null = null;

  onPageRemoving(event: any) {
    if (event.args.oldPage.items.length == 0) return;
    event.args.cancel = true;
    Dialogs.showConfirmDialog("Confirm", "Unsaved changes, close anyway?", (result: ModalResult) => {
      if (result == ModalResult.OK) event.sender.document.removePage(event.args.oldPage);
    }, document.querySelector(".main") as HTMLDivElement,
      (document.getElementById("theme") as HTMLSelectElement).value);
  }

  onAlignmentChange(e: any) {
    this.tabAlignment = +e.target.value;
  }

  onShowNavChange(e: any) {
    this.showNavigationButtons = (<HTMLInputElement>e.target).checked;
  }
  
  onShowAddChange(e: any) {
    this.showAddButton = (<HTMLInputElement>e.target).checked;
  }
  onShowCloseChange(e: any) {
    this.showTabCloseButtons = (<HTMLInputElement>e.target).checked;
  }
  onThemeChange(e: any) {
    var t = Diagramming.Theme.fromId(e.target.value);
    this.diagramViewControl.control.setTheme(t, true);
  }
}