﻿
/// <reference path="Scripts/diagramming.compat.d.ts" />

MindFusion.Diagramming.CompatConfig.propFunctions = true;

document.addEventListener("DOMContentLoaded", function () {
    // create the DiagramView control
    var diagramView = MindFusion.Diagramming.DiagramView.create(<HTMLCanvasElement>document.getElementById("diagram"));
    diagramView.setBehavior(MindFusion.Diagramming.Behavior.DrawLinks);
    diagramView.allowInplaceEdit = true;

    var diagram = diagramView.diagram;
    diagram.backBrush = "#eff7fa";
    diagram.linkHeadShapeSize = 2;
    diagram.routeLinks = true;

    // create the Overview control
    var overview = MindFusion.Diagramming.Overview.create(<HTMLCanvasElement>document.getElementById("overview"));
    overview.setDiagramView(diagramView);

    // create the NodeListView control
    var nodeList = MindFusion.Diagramming.NodeListView.create(<HTMLCanvasElement>document.getElementById("nodeList"));
    nodeList.iconSize = new MindFusion.Drawing.Size(50, 50);

    // add some nodes to the NodeListView
    var container = new MindFusion.Diagramming.ContainerNode(diagram);
    nodeList.addNode(container, "Container");

    var shapes = ["Actor", "Decision", "Process"];
    for (var i = 0; i < shapes.length; ++i) {
        var node = new MindFusion.Diagramming.ShapeNode(diagram);
        node.text = shapes[i];
        node.shape = shapes[i];
        node.brush = "orange";
        node.effects.push(new MindFusion.Diagramming.GlassEffect());
        nodeList.addNode(node, shapes[i]);
    }

    testNodes();

});

function testNodes()
{
    var diagram = MindFusion.Diagramming.DiagramView.find("diagram").diagram;

    // create a Container node
    var container = diagram.factory.createContainerNode(10, 20, 140, 160);
    container.foldable = true;
    container.text = "Container";
    container.handlesStyle = MindFusion.Diagramming.HandlesStyle.HatchHandles3;

    // create a Table node
    var table = diagram.factory.createTableNode(20, 20, 62, 42);
    table.redimTable(2, 6);
    table.getColumn(1).columnStyle = MindFusion.Diagramming.ColumnStyle.AutoWidth;
    table.text = ("Preparation");
    table.captionBackBrush = ("#9caac6");
    table.captionFont = new MindFusion.Drawing.Font("sans-serif", 3, true, true);
    table.allowResizeRows = true;
    table.allowResizeColumns = true;
    table.expandable = true;

    var cell = table.getCell(0, 0);
    cell.columnSpan = 2;
    cell.text = "Calculate Price";
    cell.textAlignment = MindFusion.Diagramming.Alignment.Center;
    cell.textColor = "#2d3956";
    cell.brush = "#9caac6";

    var cell = table.getCell(0, 3);
    cell.columnSpan = 2;
    cell.text = "Print Papers";
    cell.textAlignment = MindFusion.Diagramming.Alignment.Center;
    cell.textColor = "#2d3956";
    cell.brush = "#9caac6";

    var cell = table.getCell(0, 1);
    cell.rowSpan = 2;
    cell.imageLocation = "./icon1.png";

    var cell = table.getCell(0, 4);
    cell.rowSpan = 2;
    cell.imageLocation ="./icon2.png";

    var preparation_tasks = ["Distance", "Cargo Weight", "Invoice", "Track Number"];

    for (var i = 1; i <= 4; i++) {
        var row = i <= 2 ? i : i + 1;
        var cell = table.getCell(1, row);
        cell.text = preparation_tasks[i - 1];
        cell.textAlignment = MindFusion.Diagramming.Alignment.Far;
    }

    container.add(table);

    // create a Shape node
    var shapeNode = diagram.factory.createShapeNode(20, 20, 20, 20);
    // enable legacy style property getters and setters by setting Diagramming.CompatConfig.propFunctions to true.
    shapeNode.setShape(MindFusion.Diagramming.Shape.fromId("Decision"));
    shapeNode.setBrush({ type: "LinearGradientBrush", color1: "orange", color2: "white", angle: 20 });
    shapeNode.setFont(new MindFusion.Drawing.Font("Arial", 4));
    shapeNode.setEnableStyledText(true);
    shapeNode.setText("<i>Task 2</i>");
    shapeNode.setTextColor("#000");
    shapeNode.setTooltip("This is the second task");
    shapeNode.anchorPattern = MindFusion.Diagramming.AnchorPattern.fromId("TopInBottomOut");
    container.add(shapeNode);

    // create a TreeView node
    var treeView = diagram.factory.createTreeViewNode(140, 20, 50, 56);
    treeView.text = "Category";
    treeView.shape = MindFusion.Diagramming.SimpleShape.RoundedRectangle;
    treeView.brush = "lightyellow";
    treeView.fromObject(
        [{
            text: "Name",
            imageLocation: "./icon1.png"
        },
        {
            text: "Description"
        },
        {
            text: "Product",
            textColor: "orange",
            children: [{ text: "Name" }, { text: "QuantityPerUnit" }, { text: "UnitPrice" }]

        }]
    );

    // create an SvgNode
    var svgNode = new MindFusion.Diagramming.SvgNode(diagram);
    svgNode.transparent = true;
    var content = new MindFusion.Diagramming.SvgContent();
    content.parse("./sign.svg");
    svgNode.content = content;
    diagram.addItem(svgNode);
    container.add(svgNode);

    // add links between nodes in container
    diagram.factory.createDiagramLink(table, shapeNode);
    diagram.factory.createDiagramLink(table, svgNode);

    // arrange nodes in container
    var treeLayout = new MindFusion.Graphs.TreeLayout();
    treeLayout.linkType = MindFusion.Graphs.TreeLayoutLinkType.Cascading;
    treeLayout.levelDistance = treeLayout.nodeDistance = 16;
    container.arrange(treeLayout);

    // add a link with label
    var link2 = diagram.factory.createDiagramLink(table, treeView);
    link2.headShape = null;
    link2.pen = "orange";
    link2.strokeThickness = 1.5;
    link2.originIndex = 4;
    link2.destinationIndex = 2;
    link2.addLabel("Product #");
}