import React, { useState, useRef } from 'react';
import Info from './Info';
import * as Drawing from '@mindfusion/drawing';
import * as Diagramming from '@mindfusion/diagramming';
import * as Graphs from '@mindfusion/graphs';
import { DiagramView, NodeListView } from '@mindfusion/diagramming-react';

const onLinkCreated = (sender, args) => {
  var link = args.link;
  link.baseShape = "";
  link.headShape = "";
  link.strokeThickness = 3.0;
}

const onNodeCreated = (sender, args) => {
  var node = args.node;
  if (node instanceof Diagramming.SvgNode) {
    node.transparent = false;
    node.shape = "Ellipse";
    node.stroke = "orange";
    node.strokeThickness = 3;
    node.font = new Drawing.Font("sans-serif", 4);
  }
}

const onLayout = (diagram) => {
  var layout = new Graphs.TreeLayout();
  diagram.arrange(layout);
}

const initNodeListView = () => {
  // create the nodes for the NodeListView
  var nodes = [];
  var node = new Diagramming.ShapeNode();
  node.text = "text";
  node.shape = "Ellipse";
  node.pen = "gray";
  node.brush = "white";
  node.bounds = new Drawing.Rect(0, 0, 48, 48);
  node.enableStyledText = true;
  node.font = new Drawing.Font("sans-serif", 12, true);
  node.strokeThickness = 2;
  nodes.push(node);

  // add some nodes to the NodeListView
  var svgImages = ["account", "alarm", "book", "calendar", "computer", "key"];
  var svgNode;
  for (var i = 1; i <= svgImages.length; ++i) {
    svgNode = new Diagramming.SvgNode();
    svgNode.transparent = true;
    var content = new Diagramming.SvgContent();
    content.parse(require("./assets/" + svgImages[i - 1] + ".svg"));
    svgNode.content = content;
    nodes.push(svgNode);
  }

  return nodes;
}

const addNode = (element) => {
  var node = new Diagramming.ShapeNode();
  node.shape = Diagramming.Shapes.Star();
  element.current.addNode(node);
}

function OrgChart() {
  const [diagram] = useState(new Diagramming.Diagram());
  const nodeListElement = useRef(null);

  //styling
  var shapeNodeStyle = new Diagramming.Style();
  shapeNodeStyle.brush = { type: 'SolidBrush', color: '#e0e9e9' };
  shapeNodeStyle.stroke = "Orange";
  shapeNodeStyle.fontName = "Verdana";
  shapeNodeStyle.fontSize = 9;
  shapeNodeStyle.nodeEffects = [new Diagramming.GlassEffect()];
  diagram.style = shapeNodeStyle;

  return (
    <div className="App">
      <div className="header">
        <button onClick={() => onLayout(diagram)}>Apply layout</button>
        <button onClick={() => addNode(nodeListElement)}>Add Node</button>
      </div>

      <div className="container">
        <div className="main">
          <div className="sidebar-left" style={{ flexBasis: '120px' }}>
            <NodeListView
              id="nodeListView"
              iconSize={new Drawing.Size(60, 60)}
              nodes={initNodeListView()}
              style={{ height: 'auto' }}
              ref={nodeListElement}
            ></NodeListView>
          </div>
          <div className="main">
            <DiagramView diagram={diagram}
              id="diagram1"
              allowInplaceEdit={true}
              behavior={Diagramming.Behavior.DrawLinks}
              onNodeCreated={(sender, args) => onNodeCreated(sender, args)}
              onLinkCreated={(sender, args) => onLinkCreated(sender, args)}
              style={{ position: "absolute", width: 'auto', height: 'auto', left: 0, right: 0, top: 0, bottom: 0 }} />
          </div>
        </div>
        <div className="sidebar">
          <h1>About this sample</h1>
          <p>This sample shows how to build an application that allows the users to create a
            diagram with SVG nodes that hold icons and text.</p>
          <Info />
        </div>
      </div>

      <div className="footer">
        <p>Copyright 2024 MindFusion LLC.</p>
      </div>

    </div>
  );
}



export default OrgChart;
